@@ -17,6 +17,7 @@
  *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QDateTime>
 #include <QTime>
 
 #include "bcdclockwidget.h"
@@ -86,7 +87,7 @@ QSize BcdClockWidget::sizeHint(){
 }
 
 void BcdClockWidget::updateTime(){
-    QTime time = QTime::currentTime();
+    QTime time = QDateTime::currentDateTime().time();
 
     if(secondsOneWidget != NULL){
         secondsOneWidget->updateValue(time.second() % 10);
