@@ -17,11 +17,10 @@
  *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QSettings>
+#include <QDateTime>
 #include <QTime>
 
 #include "binaryclockwidget.h"
-#include "settingsdialog.h"
 
 BinaryClockWidget::BinaryClockWidget(QWidget *parent) :
     ClockWidget(parent)
@@ -70,7 +69,7 @@ QSize BinaryClockWidget::sizeHint(){
 }
 
 void BinaryClockWidget::updateTime(){
-    QTime time = QTime::currentTime();
+    QTime time = QDateTime::currentDateTime().time();
 
     if(secondsWidget != NULL){
         secondsWidget->updateValue(time.second());
