@@ -24,6 +24,7 @@
 #include <QAction>
 #include <QMenu>
 #include <QMouseEvent>
+#include <QSystemTrayIcon>
 #endif
 
 #include <QPaintEvent>
@@ -45,6 +46,7 @@ public slots:
 
 signals:
     void resumeClock(bool resume);
+    void settingsChanged();
 
 protected:
     void paintEvent(QPaintEvent *event);
@@ -60,20 +62,31 @@ private:
     void applySettings();
 
 #ifndef Q_WS_MAEMO_5
+
+protected slots:
+    void close();
+
 protected:
     void mouseMoveEvent(QMouseEvent *);
     void mousePressEvent(QMouseEvent *event);
 
-private:
-    QPoint position;
+private slots:
+    void triggerHide();
 
-    QMenu *menu;
+private:
+    QPoint  position;
+
+    QMenu   *menu;
     QAction *closeAction;
+    QAction *hideAction;
     QAction *settingsAction;
 
-    bool transparency;
+    bool    transparency;
 
-    void createMenu();
+    QSystemTrayIcon *tray;
+
+    void    createMenu();
+    void    createTray();
 #endif
 };
 
